thousands_separator_formatter library

A TextInputFormatter that inserts thousands separators as the user types.

See ThousandsSeparatorTextInputFormatter.

Classes

ThousandsSeparatorTextInputFormatter
A TextInputFormatter that inserts a grouping separator between every groupSize characters of the integer portion of the input, as you type.